import { DocumentClient } from 'aws-sdk/clients/dynamodb';
import * as Umzug from 'umzug';
import DynamoDBStorage from './storages/dynamodb';
export { DynamoDBStorage };
export interface MigratorOptions {
    dynamodb?: DocumentClient;
    tableName?: string;
}
export declare class Migrator {
    private umzug;
    private generator;
    /**
     * Migrator factory function, creates an umzug instance with dynamodb storage.
     * @param options
     * @param options.dynamodb - a DynamoDB document client instance
     * @param options.tableName - a name of migration table in DynamoDB
     */
    constructor({ dynamodb, tableName }?: MigratorOptions);
    generate(migrationName: string): Promise<void>;
    execute(options?: Umzug.ExecuteOptions): Promise<Umzug.Migration[]>;
    pending(): Promise<Umzug.Migration[]>;
    executed(): Promise<Umzug.Migration[]>;
    up(options?: any): Promise<Umzug.Migration[]>;
    down(options?: any): Promise<Umzug.Migration[]>;
}
/**
 * Migrator instance with options by default.
 */
export declare const defaultMigrator: Migrator;
