"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const dynamodb_1 = require("aws-sdk/clients/dynamodb");
const node_plop_1 = require("node-plop/lib/node-plop");
const Umzug = require("umzug");
const path_1 = require("./helpers/path");
const dynamodb_2 = require("./storages/dynamodb");
exports.DynamoDBStorage = dynamodb_2.default;
class Migrator {
    /**
     * Migrator factory function, creates an umzug instance with dynamodb storage.
     * @param options
     * @param options.dynamodb - a DynamoDB document client instance
     * @param options.tableName - a name of migration table in DynamoDB
     */
    constructor({ dynamodb, tableName } = {}) {
        dynamodb = dynamodb || new dynamodb_1.DocumentClient();
        tableName = tableName || 'migrations';
        this.umzug = new Umzug({
            storage: new dynamodb_2.default({ dynamodb, tableName }),
            migrations: {
                params: [dynamodb],
            },
            logging: function (...args) {
                console.log.apply(null, args);
            }
        });
        const plop = node_plop_1.default('.plop/plopfile.js');
        this.generator = plop.getGenerator('migration');
    }
    generate(migrationName) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.generator.runActions({ timestamp: path_1.getCurrentYYYYMMDDHHmms(), name: migrationName });
        });
    }
    execute(options) {
        return this.umzug.execute(options);
    }
    pending() {
        return this.umzug.pending();
    }
    executed() {
        return this.umzug.executed();
    }
    up(options) {
        return this.umzug.up(options);
    }
    down(options) {
        return this.umzug.down(options);
    }
}
exports.Migrator = Migrator;
/**
 * Migrator instance with options by default.
 */
exports.defaultMigrator = new Migrator();
